TinyArc

Struct TinyArc 

pub struct TinyArc<T>(/* private fields */);
A thread-safe reference-counting tiny pointer. As with all types of this crate, memory is allocated on the heap. It is equivalent to std::sync::Arc.

use tinypointers::TinyArc;

let x = TinyArc::new(42);
let y = x.clone();
println!("{}", *x); // prints 42
println!("{}", *y); // prints 42
// both x and y point to the same memory location

Implementations

Source

impl<T> TinyArc<T>

pub fn new(value: T) -> Self

Allocates memory on the heap and then places value into it.

Example
use tinypointers::TinyArc;

let x = TinyArc::new(42);
pub fn new_cyclic<F>(data_fn: F) -> Self
where F: FnOnce(TinyWeak<T>) -> T,

Constructs a new TinyArc<T> while giving you a TinyWeak<T> to the allocation, to allow you to construct a T which holds a weak pointer to itself.

new_cyclic first allocates the managed allocation for the TinyArc<T>, then calls your closure, giving it a TinyWeak<T> to this allocation, and only afterwards completes the construction of the TinyArc<T> by placing the T returned from your closure into the allocation.

Panic

Keep in mind that the TinyArc<T> is not fully constructed until TinyArc<T>::new_cyclic returns. Calling TinyWeak::upgrade will cause a panic.

pub fn as_ptr(this: &Self) -> *const T

Returns a raw pointer to the inner value.

The pointer will be valid for as long as there are strong references to this allocation.

pub fn ptr_eq(this: &Self, other: &Self) -> bool

Checks whether the two TinyArcs point to the same allocation.

pub fn downgrade(this: &Self) -> TinyWeak<T>

Creates a TinyWeak pointer to this allocation.

Weak references do not keep the allocation alive, and cannot access the inner value.